@@ -9,7 +9,6 @@ import (
 	"net/http"
 	"net/url"
 	"os"
-	"path"
 	"path/filepath"
 	"sort"
 	"strconv"
@@ -175,8 +174,7 @@ func (fs *FileServer) handler(w http.ResponseWriter, req *http.Request) {
 		return
 	}
 
-	upath = path.Clean(upath)
-	upath = filepath.Clean(upath)
+	upath = filepath.FromSlash(filepath.Clean("/" + strings.Trim(upath, "/")))
 
 	// Define absolute path
 	open := fs.Webroot + upath
@@ -412,13 +410,13 @@ func (fileS *FileServer) constructItems(fis []fs.FileInfo, relpath string, acl c
 			item.Ext = ""
 		}
 		// Set item fields
-		item.URI = url.PathEscape(path.Join(relpath, fi.Name()))
+		item.URI = url.PathEscape(filepath.Join(relpath, fi.Name()))
 		// Set QR Code link
 		scheme := "http"
 		if r.TLS != nil {
 			scheme = "https"
 		}
-		url := fmt.Sprintf("%s://%s%s", scheme, r.Host, item.URI)
+		url := fmt.Sprintf("%s://%s/%s", scheme, r.Host, strings.TrimPrefix(item.URI, "%2F"))
 		item.QRCode = template.URL(GenerateQRCode(url))
 		if fileS.Pass != "" || fileS.CACert != "" {
 			item.AuthEnabled = true
@@ -434,7 +432,7 @@ func (fileS *FileServer) constructItems(fis []fs.FileInfo, relpath string, acl c
 		// Check and resolve symlink
 		if fi.Mode()&os.ModeSymlink != 0 {
 			item.IsSymlink = true
-			item.SymlinkTarget, err = os.Readlink(path.Join(fileS.Webroot, relpath, fi.Name()))
+			item.SymlinkTarget, err = os.Readlink(filepath.Join(fileS.Webroot, relpath, fi.Name()))
 			if err != nil {
 				logger.Errorf("resolving symlink: %+v", err)
 			}
@@ -577,9 +575,7 @@ func (fs *FileServer) socket(w http.ResponseWriter, req *http.Request) {
 // deleteFile will delete a file
 func (fs *FileServer) deleteFile(w http.ResponseWriter, req *http.Request) {
 	// Get path
-	upath := req.URL.Path
-	upath = path.Clean(upath)
-	upath = filepath.Clean(upath)
+	upath := filepath.FromSlash(filepath.Clean("/" + strings.Trim(req.URL.Path, "/")))
 
 	fileCleaned, _ := url.QueryUnescape(upath)
 	if strings.Contains(fileCleaned, "..") {
@@ -616,9 +612,7 @@ func (fs *FileServer) CreateShareHandler(w http.ResponseWriter, r *http.Request)
 		return
 	}
 
-	upath := r.URL.Path
-	upath = path.Clean(upath)
-	upath = filepath.Clean(upath)
+	upath := filepath.FromSlash(filepath.Clean("/" + strings.Trim(r.URL.Path, "/")))
 
 	var expires time.Time
 	var downloadLimit int
@@ -634,7 +628,7 @@ func (fs *FileServer) CreateShareHandler(w http.ResponseWriter, r *http.Request)
 			logger.LogRequest(r, 400, fs.Verbose, fs.Webhook)
 			http.Error(w, "expires needs to be integer in seconds", http.StatusBadRequest)
 		}
-		expires = now.Add(time.Duration(seconds * int(time.Second)))
+		expires = now.Add(time.Duration(seconds) * time.Second)
 	}
 
 	// Set download limit
@@ -762,7 +756,7 @@ func (fs *FileServer) ShareHandler(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 
-	// Substract from download limit
+	// Subtract from download limit
 	if entry.DownloadLimit > 0 {
 		entry.DownloadLimit--
 	}
